@@ -33,7 +33,7 @@ import getpass
 server   = "server.mydomain.tld"
 port     = 22
 username = "foo"
-command  = "GNOME"
+command  = "XFCE"
 
 password = getpass.getpass()
 
