@@ -34,7 +34,7 @@ import threading
 server   = "server.mydomain.tld"
 port     = 22
 username = "foo"
-command  = "GNOME"
+command  = "XFCE"
 
 def my_progress_bar(ps):
 
