@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,8 +20,8 @@
 from x2go.defaults import BACKEND_SERVERSESSIONINFO_DEFAULT
 from x2go.defaults import BACKEND_SERVERSESSIONLIST_DEFAULT
 
-from _stdout import X2goServerSessionInfoSTDOUT
-from _stdout import X2goServerSessionListSTDOUT
+from _stdout import X2GoServerSessionInfoSTDOUT
+from _stdout import X2GoServerSessionListSTDOUT
 
-X2goServerSessionInfo = eval(BACKEND_SERVERSESSIONINFO_DEFAULT)
-X2goServerSessionList = eval(BACKEND_SERVERSESSIONLIST_DEFAULT)
+X2GoServerSessionInfo = eval(BACKEND_SERVERSESSIONINFO_DEFAULT)
+X2GoServerSessionList = eval(BACKEND_SERVERSESSIONLIST_DEFAULT)
