@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -19,9 +19,9 @@
 
 from x2go.defaults import BACKEND_CLIENTPRINTING_DEFAULT
 
-from _file import X2goClientPrintingFILE
-from _winreg import X2goClientPrintingWINREG
-from _gconf import X2goClientPrintingGCONF
+from _file import X2GoClientPrintingFILE
+from _winreg import X2GoClientPrintingWINREG
+from _gconf import X2GoClientPrintingGCONF
 
-X2goClientPrinting = eval(BACKEND_CLIENTPRINTING_DEFAULT)
+X2GoClientPrinting = eval(BACKEND_CLIENTPRINTING_DEFAULT)
 
