@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,9 +18,9 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-L{X2goClientPrintingFILE} class is one of Python X2go's public API classes. 
+L{X2GoClientPrintingFILE} class is one of Python X2Go's public API classes. 
 
-Retrieve an instance of this class from your L{X2goClient} instance.
+Retrieve an instance of this class from your L{X2GoClient} instance.
 Use this class in your Python X2Go based applications to access the »printing« 
 configuration of your X2Go client application.
 
@@ -41,15 +41,15 @@ import x2go.x2go_exceptions as x2go_exceptions
 
 _print_property_map = {
         'pdfview_cmd': {
-            'ini_section': 'view', 
+            'ini_section': 'view',
             'ini_option': 'command',
         },
         'save_to_folder': {
-            'ini_section': 'save', 
+            'ini_section': 'save',
             'ini_option': 'folder',
         },
         'printer': {
-            'ini_section': 'CUPS', 
+            'ini_section': 'CUPS',
             'ini_option': 'defaultprinter',
         },
         'print_cmd': {
@@ -58,13 +58,13 @@ _print_property_map = {
         },
 }
 
-class X2goClientPrintingFILE(inifiles.X2goIniFile):
+class X2GoClientPrintingFILE(inifiles.X2GoIniFile):
     """\
-    L{X2goClientPrintingFILE} provides access to the X2Go ini-like file
+    L{X2GoClientPrintingFILE} provides access to the X2Go ini-like file
     »printing« as stored in C{~/.x2goclient/printing} resp. globally
     C{/etc/x2goclient/printing}.
 
-    An instance of L{X2goClientPrintingFILE} is created on each incoming
+    An instance of L{X2GoClientPrintingFILE} is created on each incoming
     print job. This facilitates that on every print job the print action
     for this job is derived from the »printing« configuration file.
 
@@ -81,18 +81,18 @@ class X2goClientPrintingFILE(inifiles.X2goIniFile):
             directory filename)
         @type config_files: C{list}
         @param defaults: a cascaded Python dicitionary structure with ini file defaults (to override 
-            Python X2go's hard coded defaults in L{defaults}
+            Python X2Go's hard coded defaults in L{defaults}
         @type defaults: C{dict}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintAction} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintAction} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         self.client_instance = client_instance
-        inifiles.X2goIniFile.__init__(self, config_files, defaults=defaults, logger=logger, loglevel=loglevel)
+        inifiles.X2GoIniFile.__init__(self, config_files, defaults=defaults, logger=logger, loglevel=loglevel)
 
         self._detect_print_action()
 
@@ -108,23 +108,23 @@ class X2goClientPrintingFILE(inifiles.X2goIniFile):
         _show_dialog = self.get('General', 'showdialog', key_type=types.BooleanType)
 
         if _show_dialog and self.client_instance is not None:
-            self._print_action = printactions.X2goPrintActionDIALOG(client_instance=self.client_instance, logger=self.logger)
+            self._print_action = printactions.X2GoPrintActionDIALOG(client_instance=self.client_instance, logger=self.logger)
 
         elif _general_pdfview and _view_open:
             _view_command = self.get('view', 'command')
-            self._print_action = printactions.X2goPrintActionPDFVIEW(client_instance=self.client_instance, pdfview_cmd=_view_command, logger=self.logger)
+            self._print_action = printactions.X2GoPrintActionPDFVIEW(client_instance=self.client_instance, pdfview_cmd=_view_command, logger=self.logger)
 
         elif _general_pdfview and not _view_open:
             _safe_folder = self.get('save', 'folder')
-            self._print_action = printactions.X2goPrintActionPDFSAVE(client_instance=self.client_instance, save_to_folder=_safe_folder, logger=self.logger)
+            self._print_action = printactions.X2GoPrintActionPDFSAVE(client_instance=self.client_instance, save_to_folder=_safe_folder, logger=self.logger)
 
         elif not _general_pdfview and not _print_startcmd:
             _cups_defaultprinter = self.get('CUPS', 'defaultprinter')
-            self._print_action = printactions.X2goPrintActionPRINT(client_instance=self.client_instance, printer=_cups_defaultprinter, logger=self.logger)
+            self._print_action = printactions.X2GoPrintActionPRINT(client_instance=self.client_instance, printer=_cups_defaultprinter, logger=self.logger)
 
         elif not _general_pdfview and _print_startcmd:
             _print_command = self.get('print', 'command')
-            self._print_action = printactions.X2goPrintActionPRINTCMD(client_instance=self.client_instance, print_cmd=_print_command, logger=self.logger)
+            self._print_action = printactions.X2GoPrintActionPRINTCMD(client_instance=self.client_instance, print_cmd=_print_command, logger=self.logger)
 
     @property
     def print_action(self):
@@ -173,7 +173,7 @@ class X2goClientPrintingFILE(inifiles.X2goIniFile):
         @return: the stored value for C{<print_property>}
         @rtype: C{str}
 
-        @raise X2goClientPrintingException: if the printing property does not exist
+        @raise X2GoClientPrintingException: if the printing property does not exist
 
         """
         if print_property in _print_property_map.keys():
@@ -181,7 +181,7 @@ class X2goClientPrintingFILE(inifiles.X2goIniFile):
             _ini_option = _print_property_map[print_property]['ini_option']
             return self.get_value(_ini_section, _ini_option)
         else:
-            raise x2go_exceptions.X2goClientPrintingException('No such X2Go client printing property ,,%s\'\'' % print_property)
+            raise x2go_exceptions.X2GoClientPrintingException('No such X2Go client printing property ,,%s\'\'' % print_property)
 
     def set_property(self, print_property, value):
         """\
@@ -192,7 +192,7 @@ class X2goClientPrintingFILE(inifiles.X2goIniFile):
         @param value: the value to be stored as C{<print_property>}
         @rtype: C{str}
 
-        @raise X2goClientPrintingException: if the printing property does not exist or if there is a type mismatch
+        @raise X2GoClientPrintingException: if the printing property does not exist or if there is a type mismatch
 
         """
         if print_property in _print_property_map.keys():
@@ -202,10 +202,10 @@ class X2goClientPrintingFILE(inifiles.X2goIniFile):
             if type(value) is types.UnicodeType:
                 value = value.encode('utf-8')
             if  _default_type != type(value):
-                raise x2go_exceptions.X2goClientPrintingException('Type mismatch error for property ,,%s\'\' - is: %s, should be: %s' % (print_property, str(type(value)), str(_default_type)))
+                raise x2go_exceptions.X2GoClientPrintingException('Type mismatch error for property ,,%s\'\' - is: %s, should be: %s' % (print_property, str(type(value)), str(_default_type)))
             self.update_value(_ini_section, _ini_option, value)
         else:
-            raise x2go_exceptions.X2goClientPrintingException('No such X2Go client printing property ,,%s\'\'' % print_property)
+            raise x2go_exceptions.X2GoClientPrintingException('No such X2Go client printing property ,,%s\'\'' % print_property)
 
     def store_print_action(self, print_action, **print_properties):
         """\
