@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,9 +18,9 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-L{X2goClientPrintingGCONF} class is one of Python X2go's public API classes. 
+L{X2GoClientPrintingGCONF} class is one of Python X2Go's public API classes. 
 
-Retrieve an instance of this class from your L{X2goClient} instance.
+Retrieve an instance of this class from your L{X2GoClient} instance.
 Use this class in your Python X2Go based applications to access the »printing« 
 configuration of your X2Go client application.
 
@@ -36,14 +36,14 @@ from x2go.defaults import X2GO_CLIENTPRINTING_DEFAULTS as _X2GO_CLIENTPRINTING_D
 from x2go.defaults import X2GO_PRINTING_CONFIGFILES as _X2GO_PRINTING_CONFIGFILES
 import x2go.inifiles as inifiles
 
-from x2go.x2go_exceptions import X2goNotImplementedYetException
+from x2go.x2go_exceptions import X2GoNotImplementedYetException
 
-class X2goClientPrintingGCONF(inifiles.X2goIniFile):
+class X2GoClientPrintingGCONF(inifiles.X2GoIniFile):
     """\
-    L{X2goClientPrintingGCONF} provides access to the GCONF based configuration
+    L{X2GoClientPrintingGCONF} provides access to the GCONF based configuration
     of the X2Go client printing setup.
 
-    An instance of L{X2goClientPrintingGCONF} is created on each incoming
+    An instance of L{X2GoClientPrintingGCONF} is created on each incoming
     print job. This facilitates that on every print job the print action
     for this job is derived from the »printing« configuration file.
 
@@ -56,16 +56,16 @@ class X2goClientPrintingGCONF(inifiles.X2goIniFile):
     def __init__(self, defaults=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
         @param defaults: a cascaded Python dicitionary structure with ini file defaults (to override 
-            Python X2go's hard coded defaults in L{defaults}
+            Python X2Go's hard coded defaults in L{defaults}
         @type defaults: C{dict}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintAction} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintAction} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
-        raise X2goNotImplementedYetException('GCONF backend support is not implemented yet')
+        raise X2GoNotImplementedYetException('GCONF backend support is not implemented yet')
 
 
