@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -19,10 +19,10 @@
 
 from x2go.defaults import BACKEND_SESSIONPROFILES_DEFAULT
 
-from _file import X2goSessionProfilesFILE
-from _winreg import X2goSessionProfilesWINREG
-from _httpsbroker import X2goSessionProfilesHTTPSBROKER
-from _gconf import X2goSessionProfilesGCONF
+from _file import X2GoSessionProfilesFILE
+from _winreg import X2GoSessionProfilesWINREG
+from _httpsbroker import X2GoSessionProfilesHTTPSBROKER
+from _gconf import X2GoSessionProfilesGCONF
 
-X2goSessionProfiles = eval(BACKEND_SESSIONPROFILES_DEFAULT)
+X2GoSessionProfiles = eval(BACKEND_SESSIONPROFILES_DEFAULT)
 
