@@ -154,7 +154,7 @@ class X2GoSessionProfilesFILE(inifiles.X2GoIniFile):
             self.iniConfig.remove_section(profile_id)
             try: self._cached_profile_ids.remove(profile_id)
             except ValueError: pass
-            self.add_profile(profile_id=None, **_config)
+            self.add_profile(profile_id=None, force_add=True, **_config)
         self._profiles_need_profile_id_renewal = []
         self._cached_profile_ids = []
         self._cached_profile_names = []
@@ -346,7 +346,7 @@ class X2GoSessionProfilesFILE(inifiles.X2GoIniFile):
         else:
             return ''
 
-    def add_profile(self, profile_id=None, **kwargs):
+    def add_profile(self, profile_id=None, force_add=False, **kwargs):
         """\
         Add a new session profile.
 
@@ -359,9 +359,15 @@ class X2GoSessionProfilesFILE(inifiles.X2GoIniFile):
         @rtype: C{str}
 
         """
-        if profile_id is None:
+        if profile_id is None or profile_id in self.profile_ids:
             profile_id = utils._genSessionProfileId()
 
+        if 'name' not in kwargs.keys():
+            raise X2GoProfileException('session profile parameter ,,name\'\' is missing in method parameters')
+
+        if kwargs['name'] in self.profile_names and not force_add:
+            raise X2GoProfileException('a profile of name ,,%s\'\' already exists' % kwargs['name'])
+
         for key, value in kwargs.items():
             self.update_value(None, key, value, profile_id=profile_id)
 
