@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,9 +18,9 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-L{X2goSessionProfiles} class - managing x2goclient session profiles.
+L{X2GoSessionProfiles} class - managing x2goclient session profiles.
 
-L{X2goSessionProfiles} is a public API class. Use this class in your Python X2Go based 
+L{X2GoSessionProfiles} is a public API class. Use this class in your Python X2Go based 
 applications.
 
 """
@@ -32,9 +32,9 @@ from x2go.defaults import X2GO_SESSIONPROFILE_DEFAULTS
 import x2go.inifiles as inifiles
 import x2go.log as log
 
-from x2go.x2go_exceptions import X2goNotImplementedYetException
+from x2go.x2go_exceptions import X2GoNotImplementedYetException
 
-class X2goSessionProfilesGCONF(inifiles.X2goIniFile):
+class X2GoSessionProfilesGCONF(inifiles.X2GoIniFile):
 
     defaultSessionProfile = X2GO_SESSIONPROFILE_DEFAULTS
     _non_profile_sections = ('embedded')
@@ -45,12 +45,12 @@ class X2goSessionProfilesGCONF(inifiles.X2goIniFile):
 
         @param session_profile_defaults: a default session profile
         @type session_profile_defaults: C{dict}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goSessionProfilesGCONF} constructor
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoSessionProfilesGCONF} constructor
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
-        raise X2goNotImplementedYetException('GCONF backend support is not implemented yet')
+        raise X2GoNotImplementedYetException('GCONF backend support is not implemented yet')
