@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -19,6 +19,6 @@
 
 from x2go.defaults import BACKEND_PROXY_DEFAULT
 
-from _nx3 import X2goProxyNX3
+from _nx3 import X2GoProxyNX3
 
-X2goProxy = eval(BACKEND_PROXY_DEFAULT)
+X2GoProxy = eval(BACKEND_PROXY_DEFAULT)
