@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goProxy classes - proxying your connection through NX3 and others.
+X2GoProxy classes - proxying your connection through NX3 and others.
 
 """
 __NAME__ = 'x2goproxynx3-pylib'
@@ -32,20 +32,20 @@ import base
 
 from x2go.defaults import X2GOCLIENT_OS as _X2GOCLIENT_OS
 
-class X2goProxyNX3(base.X2goProxyBASE):
+class X2GoProxyNX3(base.X2GoProxyBASE):
     """\
-    X2goNX3Proxy is a NX version 3 based X2Go proxy connection class.
+    X2GoNX3Proxy is a NX version 3 based X2Go proxy connection class.
 
-    It basically fills L{X2goProxyBASE} variables with sensible content. Its 
+    It basically fills L{X2GoProxyBASE} variables with sensible content. Its 
     methods mostly wrap around the corresponding methods of the parent class.
 
     """
     def __init__(self, *args, **kwargs):
         """\
-        For available parameters refer to L{X2goProxyBASE} class documentation.
+        For available parameters refer to L{X2GoProxyBASE} class documentation.
 
         """
-        base.X2goProxyBASE.__init__(self, *args, **kwargs)
+        base.X2GoProxyBASE.__init__(self, *args, **kwargs)
 
         # setting some default environment variables, nxproxy paths etc.
         if _X2GOCLIENT_OS == "Windows":
@@ -76,7 +76,7 @@ class X2goProxyNX3(base.X2goProxyBASE):
                 "connect=127.0.0.1",
                 "clipboard=1",
                 "cookie=%s" % self.session_info.cookie,
-                "port=%d" % self.session_info.graphics_port,
+                "port=%s" % self.session_info.graphics_port,
                 "errors=%s" % os.path.join(".", "..", "S-%s" % self.session_info.name, self.session_log, ),
             ]
         else:
@@ -87,7 +87,7 @@ class X2goProxyNX3(base.X2goProxyBASE):
                 "connect=127.0.0.1",
                 "clipboard=1",
                 "cookie=%s" % self.session_info.cookie,
-                "port=%d" % self.session_info.graphics_port,
+                "port=%s" % self.session_info.graphics_port,
                 "errors=%s" % os.path.join(self.session_info.local_container, self.session_log, ),
             ]
 
@@ -136,7 +136,7 @@ class X2goProxyNX3(base.X2goProxyBASE):
         self.logger('NX3 Proxy mode is server, cookie=%s, host=127.0.0.1, port=%s.' % (self.session_info.cookie, self.session_info.graphics_port,), loglevel=log.loglevel_DEBUG)
         self.logger('NX3 proxy writes session log to %s.' % os.path.join(self.session_info.local_container, 'session.log'), loglevel=log.loglevel_DEBUG)
 
-        p, p_ok = base.X2goProxyBASE.start_proxy(self)
+        p, p_ok = base.X2GoProxyBASE.start_proxy(self)
 
         if self.ok():
             self.logger('NX3 proxy is up and running.', loglevel=log.loglevel_INFO)
