@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goProxyBASE class - proxying your connection through NX3 and others.
+X2GoProxyBASE class - proxying your connection through NX3 and others.
 
 """
 __NAME__ = 'x2goproxy-pylib'
@@ -47,12 +47,12 @@ from x2go.defaults import LOCAL_HOME as _LOCAL_HOME
 from x2go.defaults import X2GO_SESSIONS_ROOTDIR as _X2GO_SESSIONS_ROOTDIR
 
 
-class X2goProxyBASE(threading.Thread):
+class X2GoProxyBASE(threading.Thread):
     """\
-    X2goProxy is an abstract class for X2Go proxy connections.
+    X2GoProxy is an abstract class for X2Go proxy connections.
 
     This class needs to be inherited from a concrete proxy class. Only 
-    currently available proxy class is: L{X2goProxyNX3}.
+    currently available proxy class is: L{X2GoProxyNX3}.
 
     """
     PROXY_CMD = ''
@@ -75,30 +75,30 @@ class X2goProxyBASE(threading.Thread):
                  session_instance=None,
                  logger=None, loglevel=log.loglevel_DEFAULT, ):
         """\
-        @param session_info: session information provided as an C{X2goServerSessionInfo*} backend
+        @param session_info: session information provided as an C{X2GoServerSessionInfo*} backend
             instance
-        @type session_info: C{X2goServerSessionInfo*} instance
+        @type session_info: C{X2GoServerSessionInfo*} instance
         @param ssh_transport: SSH transport object from C{paramiko.SSHClient}
         @type ssh_transport: C{paramiko.Transport} instance
         @param session_log: name of the proxy's session logfile
         @type session_log: C{str}
         @param sessions_rootdir: base dir where X2Go session files are stored (by default: ~/.x2go)
         @type sessions_rootdir: C{str}
-        @param proxy_options: a set of very C{X2goProxy*} backend specific options; any option that is not known
-            to the C{X2goProxy*} backend will simply be ignored
+        @param proxy_options: a set of very C{X2GoProxy*} backend specific options; any option that is not known
+            to the C{X2GoProxy*} backend will simply be ignored
         @type proxy_options: C{dict}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goProxy} constructor
-        @param session_instance: the L{X2goSession} instance this C{X2goProxy*} instance belongs to
-        @type session_instance: L{X2goSession} instance
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoProxy} constructor
+        @param session_instance: the L{X2GoSession} instance this C{X2GoProxy*} instance belongs to
+        @type session_instance: L{X2GoSession} instance
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: int
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -180,10 +180,10 @@ class X2goProxyBASE(threading.Thread):
             if self.ssh_transport.getpeername() in ('::1', '127.0.0.1', 'localhost', 'localhost.localdomain'):
                 local_graphics_port += 10000
         except socket.error:
-            raise x2go_exceptions.X2goControlSessionException('The control session has died unexpectedly.')
+            raise x2go_exceptions.X2GoControlSessionException('The control session has died unexpectedly.')
         local_graphics_port = utils.detect_unused_port(preferred_port=local_graphics_port)
 
-        self.fw_tunnel = forward.start_forward_tunnel(local_port=local_graphics_port, 
+        self.fw_tunnel = forward.start_forward_tunnel(local_port=local_graphics_port,
                                                       remote_port=self.session_info.graphics_port,
                                                       ssh_transport=self.ssh_transport,
                                                       session_instance=self.session_instance,
@@ -244,7 +244,7 @@ class X2goProxyBASE(threading.Thread):
 
             1. remove processed proxy_options from self.proxy_options
             2. once you have finished processing the proxy_options call
-            the parent class method X2goProxyBASE.process_proxy_options()
+            the parent class method X2GoProxyBASE.process_proxy_options()
 
         """
         # do the logging of remaining options
