@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -19,9 +19,9 @@
 
 from x2go.defaults import BACKEND_CLIENTSETTINGS_DEFAULT
 
-from _file import X2goClientSettingsFILE
-from _gconf import X2goClientSettingsGCONF
-from _winreg import X2goClientSettingsWINREG
+from _file import X2GoClientSettingsFILE
+from _gconf import X2GoClientSettingsGCONF
+from _winreg import X2GoClientSettingsWINREG
 
-X2goClientSettings = eval(BACKEND_CLIENTSETTINGS_DEFAULT)
+X2GoClientSettings = eval(BACKEND_CLIENTSETTINGS_DEFAULT)
 
