@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,10 +18,10 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goClientSettings class - managing x2goclient settings file (incl. LDAP-Support).
+X2GoClientSettings class - managing x2goclient settings file (incl. LDAP-Support).
 
-The L{X2goClientSettings} class one of Python X2go's a public API classes.
-Use this class (indirectly by retrieving it from an L{X2goClient} instance)
+The L{X2GoClientSettings} class one of Python X2Go's a public API classes.
+Use this class (indirectly by retrieving it from an L{X2GoClient} instance)
 in your Python X2Go based applications to access the
 »settings« configuration file of your X2Go client application.
 
@@ -35,20 +35,20 @@ from x2go.defaults import X2GO_CLIENTSETTINGS_DEFAULTS as _X2GO_CLIENTSETTINGS_D
 import x2go.inifiles as inifiles
 
 
-class X2goClientSettingsFILE(inifiles.X2goIniFile):
+class X2GoClientSettingsFILE(inifiles.X2GoIniFile):
     """\
-    Configuration file based settings for L{X2goClient} instances.
+    Configuration file based settings for L{X2GoClient} instances.
 
     """
     defaultValues = _X2GO_CLIENTSETTINGS_DEFAULTS
 
     def __init__(self, config_files=_X2GO_SETTINGS_CONFIGFILES, defaults=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        Constructs an L{X2goClientSettingsFILE} instance. This is normally done from within an L{X2goClient} instance.
-        You can retrieve this L{X2goClientSettingsFILE} instance with the L{X2goClient.get_client_settings()} 
+        Constructs an L{X2GoClientSettingsFILE} instance. This is normally done from within an L{X2GoClient} instance.
+        You can retrieve this L{X2GoClientSettingsFILE} instance with the L{X2GoClient.get_client_settings()} 
         method.
 
-        On construction the L{X2goClientSettingsFILE} object is filled with values from the configuration files::
+        On construction the L{X2GoClientSettingsFILE} object is filled with values from the configuration files::
 
             /etc/x2goclient/settings
             ~/.x2goclient/settings
@@ -58,4 +58,4 @@ class X2goClientSettingsFILE(inifiles.X2goIniFile):
         C{/etc/x2goclient/settings}.
 
         """
-        inifiles.X2goIniFile.__init__(self, config_files, defaults=defaults, logger=logger, loglevel=loglevel)
+        inifiles.X2GoIniFile.__init__(self, config_files, defaults=defaults, logger=logger, loglevel=loglevel)
