@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,10 +18,10 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goClientSettings class - managing x2goclient settings file (incl. LDAP-Support).
+X2GoClientSettings class - managing x2goclient settings file (incl. LDAP-Support).
 
-The L{X2goClientSettings} class one of Python X2go's a public API classes.
-Use this class (indirectly by retrieving it from an L{X2goClient} instance)
+The L{X2GoClientSettings} class one of Python X2Go's a public API classes.
+Use this class (indirectly by retrieving it from an L{X2GoClient} instance)
 in your Python X2Go based applications to access the
 »settings« configuration file of your X2Go client application.
 
@@ -34,25 +34,25 @@ from x2go.defaults import X2GO_SETTINGS_CONFIGFILES as _X2GO_SETTINGS_CONFIGFILE
 from x2go.defaults import X2GO_CLIENTSETTINGS_DEFAULTS as _X2GO_CLIENTSETTINGS_DEFAULTS
 import x2go.inifiles as inifiles
 
-from x2go.x2go_exceptions import X2goNotImplementedYetException
+from x2go.x2go_exceptions import X2GoNotImplementedYetException
 
-class X2goClientSettingsWINREG(inifiles.X2goIniFile):
+class X2GoClientSettingsWINREG(inifiles.X2GoIniFile):
     """\
-    Windows registry based settings for L{X2goClient} instances.
+    Windows registry based settings for L{X2GoClient} instances.
 
     """
     defaultValues = _X2GO_CLIENTSETTINGS_DEFAULTS
 
     def __init__(self, config_files=_X2GO_SETTINGS_CONFIGFILES, defaults=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        Constructs an L{X2goClientSettingsWINREG} instance. This is normally done from within an L{X2goClient} instance.
-        You can retrieve this L{X2goClientSettingsWINREG} instance with the L{X2goClient.get_client_settings()} 
+        Constructs an L{X2GoClientSettingsWINREG} instance. This is normally done from within an L{X2GoClient} instance.
+        You can retrieve this L{X2GoClientSettingsWINREG} instance with the L{X2GoClient.get_client_settings()} 
         method.
 
-        On construction the L{X2goClientSettings} object is filled with values from the Windows registry::
+        On construction the L{X2GoClientSettings} object is filled with values from the Windows registry::
 
             <HKLM path, FIXME: give proper locations here>
             <HKCU path, FIXME: give proper locations here>
 
         """
-        raise X2goNotImplementedYetException('WINREG backend support is not implemented yet')
+        raise X2GoNotImplementedYetException('WINREG backend support is not implemented yet')
