@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -19,6 +19,6 @@
 
 from x2go.defaults import BACKEND_TERMINALSESSION_DEFAULT
 
-from _stdout import X2goTerminalSessionSTDOUT
+from _stdout import X2GoTerminalSessionSTDOUT
 
-X2goTerminalSession = eval(BACKEND_TERMINALSESSION_DEFAULT)
+X2GoTerminalSession = eval(BACKEND_TERMINALSESSION_DEFAULT)
