@@ -1637,17 +1637,6 @@ class X2GoTerminalSessionSTDOUT(object):
 
             self._cleaned_up = True
 
-    def is_desktop_session(self):
-        """\
-        Test if this terminal session is a desktop session.
-
-        @return: C{True} if this session is of session type desktop ('D').
-        @rtype: C{bool}
-
-        """
-        self.params.rewrite_session_type()
-        return self.params.session_type == 'D'
-
     def is_rootless_session(self):
         """\
         Test if this terminal session is a rootless session.
