@@ -152,7 +152,8 @@ class X2GoListSessionsCache(object):
             self.x2go_listsessions_cache[profile_name]['mounts'] = {}
             if self.x2go_listsessions_cache[profile_name]['sessions']:
                 for session_name in self.x2go_listsessions_cache[profile_name]['sessions']:
-                    if self.client_instance.get_session_of_session_name(session_name, return_object=True, match_profile_name=profile_name).is_running():
+                    session = self.client_instance.get_session_of_session_name(session_name, return_object=True, match_profile_name=profile_name)
+                    if session is not None and session.is_running():
                         if control_session is not None and not control_session.has_session_died():
                             self.x2go_listsessions_cache[profile_name]['mounts'].update(control_session.list_mounts(session_name))
         except (x2go_exceptions.X2GoControlSessionException, AttributeError), e:
