@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -46,7 +46,7 @@ def x2go_cleanup(e=None, threads=None):
         import x2go
 
         try:
-            my_x2goclient = x2go.X2goClient(...)
+            my_x2goclient = x2go.X2GoClient(...)
 
             [... your code ...]
 
@@ -70,11 +70,11 @@ def x2go_cleanup(e=None, threads=None):
 
         # stop X2Go reverse forwarding tunnels
         for t in threads:
-            if type(t) == rforward.X2goRevFwTunnel:
+            if type(t) == rforward.X2GoRevFwTunnel:
                 t.stop_thread()
                 del t
 
-        # stop X2Go paramiko transports used by X2goTerminalSession objects
+        # stop X2Go paramiko transports used by X2GoTerminalSession objects
         for t in threads:
             if type(t) == paramiko.Transport:
                 if hasattr(t, '_x2go_session_marker'):
@@ -84,19 +84,19 @@ def x2go_cleanup(e=None, threads=None):
         # on Windows: stop the XServer that we evoked
         if _X2GOCLIENT_OS == 'Windows':
             for t in threads:
-                if type(t) == xserver.X2goXServer:
+                if type(t) == xserver.X2GoXServer:
                     t.stop_thread()
                     del t
 
         # on Windows: stop the PulseAudio daemon that we evoked
         if _X2GOCLIENT_OS == 'Windows':
             for t in threads:
-                if type(t) == pulseaudio.X2goPulseAudio:
+                if type(t) == pulseaudio.X2GoPulseAudio:
                     t.stop_thread()
                     del t
 
         for t in threads:
-            if type(t) == guardian.X2goSessionGuardian:
+            if type(t) == guardian.X2GoSessionGuardian:
                 t.stop_thread()
                 del t
 
