@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goSessionGuardian class - a guardian thread that controls X2Go session threads
+X2GoSessionGuardian class - a guardian thread that controls X2Go session threads
 and their sub-threads (like reverse forwarding tunnels, Paramiko transport threads,
 etc.).
 
@@ -34,14 +34,14 @@ import copy
 from cleanup import x2go_cleanup
 import log
 
-class X2goSessionGuardian(threading.Thread):
+class X2GoSessionGuardian(threading.Thread):
     """\
-    L{X2goSessionGuardian} thread controls X2Go session threads and their sub-threads (like 
+    L{X2GoSessionGuardian} thread controls X2Go session threads and their sub-threads (like 
     reverse forwarding tunnels, Paramiko transport threads, etc.). Its main function is
     to tidy up once a session gets interrupted (SIGTERM, SIGINT). 
 
-    There is one L{X2goSessionGuardian} for each L{X2goClient} instance (thus: for normal
-    setups there should be _one_ L{X2goClient} and _one_ L{X2goSessionGuardian} in use).
+    There is one L{X2GoSessionGuardian} for each L{X2GoClient} instance (thus: for normal
+    setups there should be _one_ L{X2GoClient} and _one_ L{X2GoSessionGuardian} in use).
 
     """
     def __init__(self, client_instance, 
@@ -54,11 +54,11 @@ class X2goSessionGuardian(threading.Thread):
                  refresh_interval=5,
                  logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param auto_update_listsessions_cache: let L{X2goSessionGuardian} refresh the session list cache for all L{X2goSession} objects
+        @param auto_update_listsessions_cache: let L{X2GoSessionGuardian} refresh the session list cache for all L{X2GoSession} objects
         @type auto_update_listsessions_cache: C{bool}
-        @param auto_update_listdesktops_cache: let L{X2goSessionGuardian} refresh desktop lists in the session list cache for all L{X2goSession} objects
+        @param auto_update_listdesktops_cache: let L{X2GoSessionGuardian} refresh desktop lists in the session list cache for all L{X2GoSession} objects
         @type auto_update_listdesktops_cache: C{bool}
-        @param auto_update_listmounts_cache: let L{X2goSessionGuardian} refresh mount lists in the session list cache for all L{X2goSession} objects
+        @param auto_update_listmounts_cache: let L{X2GoSessionGuardian} refresh mount lists in the session list cache for all L{X2GoSession} objects
         @type auto_update_listmounts_cache: C{bool}
         @param auto_update_sessionregistry: if set to C{True} the session status will be updated in regular intervals
         @type auto_update_sessionregistry: C{bool}
@@ -69,15 +69,15 @@ class X2goSessionGuardian(threading.Thread):
         @type no_auto_reg_pubapp_sessions: C{bool}
         @param refresh_interval: refresh cache and session registry every <refresh_interval> seconds
         @type refresh_interval: C{int}
-        @param logger: you can pass an L{X2goLogger} object to the L{X2goSessionGuardian} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the L{X2GoSessionGuardian} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -97,7 +97,7 @@ class X2goSessionGuardian(threading.Thread):
 
     def guardian(self):
         """\
-        The handler of this L{X2goSessionGuardian} thread.
+        The handler of this L{X2GoSessionGuardian} thread.
 
         """
         seconds = 0
@@ -132,7 +132,7 @@ class X2goSessionGuardian(threading.Thread):
 
     def stop_thread(self):
         """\
-        Stop this L{X2goSessionGuardian} thread.
+        Stop this L{X2GoSessionGuardian} thread.
 
         """
         self._keepalive = False
