@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -24,7 +24,7 @@
 #       none so far
 
 """\
-X2goProcessIniFile - helper class for parsing .ini files
+X2GoProcessIniFile - helper class for parsing .ini files
 
 """
 __NAME__ = 'x2goinifiles-pylib'
@@ -41,14 +41,14 @@ from defaults import LOCAL_HOME as _current_home
 import log
 import utils
 
-class X2goIniFile(object):
+class X2GoIniFile(object):
     """
-    Base class for processing the different ini files used by X2go
+    Base class for processing the different ini files used by X2Go
     clients. Primarily used to standardize the content of the different
     X2Go client ini file (settings, printing, sessions, xconfig).
 
     If entries are omitted in an ini file, they are filled with
-    default values (as hard coded in Python X2go), so the resulting objects 
+    default values (as hard coded in Python X2Go), so the resulting objects 
     always contain the same fields.
 
     """
@@ -66,12 +66,12 @@ class X2goIniFile(object):
             directory filename)
         @type config_files: C{list}
         @param defaults: a cascaded Python dicitionary structure with ini file defaults (to override
-            Python X2go's hard coded defaults in L{defaults}
+            Python X2Go's hard coded defaults in L{defaults}
         @type defaults: C{dict}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goIniFile} constructor
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoIniFile} constructor
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -81,7 +81,7 @@ class X2goIniFile(object):
             config_files = []
 
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -131,7 +131,7 @@ class X2goIniFile(object):
         self._fill_defaults()
 
     def __repr__(self):
-        result = 'X2goIniFile('
+        result = 'X2GoIniFile('
         for p in dir(self):
             if '__' in p or not p in self.__dict__ or type(p) is types.InstanceType: continue
             result += p + '=' + str(self.__dict__[p]) + ','
@@ -204,12 +204,20 @@ class X2goIniFile(object):
         For writing the first of the C{config_files} specified on instance construction
         that is writable will be used.
 
+        @return: C{True} if the user config file has been successfully writte, C{False} otherwise.
+        @rtype: C{bool}
+
         """
         if self.user_config_file and self.write_user_config:
-            fd = open(self.user_config_file, 'wb')
-            self.iniConfig.write(fd)
-            fd.close()
-            self.write_user_config = False
+            try:
+                fd = open(self.user_config_file, 'wb')
+                self.iniConfig.write(fd)
+                fd.close()
+                self.write_user_config = False
+                return True
+            except Exception, e:
+                print e
+        return False
 
     def get_type(self, section, key):
         """\
