@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goLogger class - flexible handling of log and debug output.
+X2GoLogger class - flexible handling of log and debug output.
 
 """
 __NAME__ = 'x2gologger-pylib'
@@ -38,13 +38,13 @@ loglevel_DEBUG_SFTPXFER = 1024
 
 loglevel_DEFAULT = loglevel_ERROR | loglevel_WARN | loglevel_NOTICE
 """\
-Default loglevel of X2goLogger objects is: NOTICE & WARN & ERROR
+Default loglevel of X2GoLogger objects is: NOTICE & WARN & ERROR
 """
 
 # Python X2Go modules
 import utils
 
-class X2goLogger(object):
+class X2GoLogger(object):
     """\
     A simple logger class, that is used by all Python X2Go classes.
 
@@ -65,9 +65,9 @@ class X2goLogger(object):
 
     def __init__(self, name=sys.argv[0], loglevel=loglevel_DEFAULT, tag=None):
         """\
-        @param name: name of the programme that uses Python X2go
+        @param name: name of the programme that uses Python X2Go
         @type name: C{str}
-        @param loglevel: log level for Python X2go
+        @param loglevel: log level for Python X2Go
         @type loglevel: C{int}
         @param tag: additional tag for all log entries
         @type tag: C{str}
@@ -184,3 +184,7 @@ class X2goLogger(object):
 
         """
         self.loglevel = self.loglevel ^ loglevel_DEBUG_SFTPXFER
+
+# compat section
+X2goLogger = X2GoLogger
+
