@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,10 +18,10 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-L{X2goPrintQueue} sets up a thread that listens for incoming print jobs.
+L{X2GoPrintQueue} sets up a thread that listens for incoming print jobs.
 
 For each incoming print job in an X2Go session's spool directory an 
-individual thread is started (L{X2goPrintJob}) that handles the processing 
+individual thread is started (L{X2GoPrintJob}) that handles the processing 
 of the incoming print job.
 
 """
@@ -39,14 +39,14 @@ import utils
 import log
 
 # we hide the default values from epydoc (that's why we transform them to _UNDERSCORE variables)
-from backends.printing import X2goClientPrinting as _X2goClientPrinting
+from backends.printing import X2GoClientPrinting as _X2GoClientPrinting
 
 from defaults import X2GO_PRINTING_FILENAME as _X2GO_PRINTING_FILENAME
 
 
-class X2goPrintQueue(threading.Thread):
+class X2GoPrintQueue(threading.Thread):
     """\
-    If X2Go printing is supported in a particular L{X2goSession} instance
+    If X2Go printing is supported in a particular L{X2GoSession} instance
     this class provides a sub-thread for handling incoming X2Go print jobs.
 
     """
@@ -63,7 +63,7 @@ class X2goPrintQueue(threading.Thread):
                  print_action=None,
                  print_action_args={},
                  client_instance=None,
-                 printing_backend=_X2goClientPrinting,
+                 printing_backend=_X2GoClientPrinting,
                  logger=None,
                  loglevel=log.loglevel_DEFAULT):
         """\
@@ -75,21 +75,21 @@ class X2goPrintQueue(threading.Thread):
         @type print_action: C{str} or instance
         @param print_action_args: depending of the chosen C{print_action} this dictionary may contain different
             values; the C{print_action_args} will be passed on to the X2Go print action instance constructor, so 
-            refer to either of these: L{X2goPrintActionPDFVIEW}, L{X2goPrintActionPRINT} et al.
-        @param client_instance: the underlying L{X2goClient} instance
+            refer to either of these: L{X2GoPrintActionPDFVIEW}, L{X2GoPrintActionPRINT} et al.
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
         @param printing_backend: the client printing configuration backend class
         @type printing_backend: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintQueue} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintQueue} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -136,7 +136,7 @@ class X2goPrintQueue(threading.Thread):
 
     def stop_thread(self):
         """\
-        Stops this L{X2goPrintQueue} thread completely.
+        Stops this L{X2GoPrintQueue} thread completely.
 
         """
         self.pause()
@@ -166,12 +166,12 @@ class X2goPrintQueue(threading.Thread):
 
     def set_print_action(self, print_action, **kwargs):
         """\
-        Modify the print action of this L{X2goPrintQueue} thread during runtime. The 
+        Modify the print action of this L{X2GoPrintQueue} thread during runtime. The 
         change of print action will be valid for the next incoming print job.
 
         As kwargs you can pass arguments for the print action class to be set. Refer
-        to the class descriptions of L{X2goPrintActionDIALOG}, L{X2goPrintActionPDFVIEW},
-        L{X2goPrintActionPRINT}, etc.
+        to the class descriptions of L{X2GoPrintActionDIALOG}, L{X2GoPrintActionPDFVIEW},
+        L{X2GoPrintActionPRINT}, etc.
 
         @param print_action: new print action to be valid for incoming print jobs
         @type print_action: C{str} or C{class}
@@ -187,7 +187,7 @@ class X2goPrintQueue(threading.Thread):
 
     def run(self):
         """\
-        Start this L{X2goPrintQueue} thread...
+        Start this L{X2GoPrintQueue} thread...
 
         """
         self.logger('starting print queue thread: %s' % repr(self), loglevel=log.loglevel_DEBUG)
@@ -201,7 +201,7 @@ class X2goPrintQueue(threading.Thread):
 
                     for _job in self._incoming_print_jobs:
                         self.logger('processing incoming X2Go print job: %s' % _job[1], loglevel=log.loglevel_NOTICE)
-                        _new_printjob_thread = X2goPrintJob(target=x2go_printjob_handler,
+                        _new_printjob_thread = X2GoPrintJob(target=x2go_printjob_handler,
                                                             kwargs={ 
                                                             'job_file': _job[0],
                                                             'pdf_file': _job[1],
@@ -222,7 +222,7 @@ class X2goPrintQueue(threading.Thread):
 def x2go_printjob_handler(job_file=None, pdf_file=None, job_title=None, print_action=None, parent_thread=None, logger=None, ):
     """\
     This function is called as a handler function for each incoming X2Go print job 
-    represented by the class L{X2goPrintJob}.
+    represented by the class L{X2GoPrintJob}.
 
     The handler function will (re-)read the »printing« configuration file (if no
     explicit C{print_action} is passed to this function...). It then will
@@ -232,11 +232,11 @@ def x2go_printjob_handler(job_file=None, pdf_file=None, job_title=None, print_ac
     @type pdf_file: C{str}
     @param job_title: human readable print job title
     @type job_title: C{str}
-    @param print_action: an instance of either of the possible C{X2goPrintActionXXX} classes
-    @type print_action: C{X2goPrintActionXXX} nstance
-    @param parent_thread: the L{X2goPrintQueue} thread that actually created this handler's L{X2goPrintJob} instance
+    @param print_action: an instance of either of the possible C{X2GoPrintActionXXX} classes
+    @type print_action: C{X2GoPrintActionXXX} nstance
+    @param parent_thread: the L{X2GoPrintQueue} thread that actually created this handler's L{X2GoPrintJob} instance
     @type parent_thread: C{obj}
-    @param logger: the L{X2goPrintQueue}'s logging instance
+    @param logger: the L{X2GoPrintQueue}'s logging instance
     @type logger: C{obj}
 
     """
@@ -277,7 +277,7 @@ def x2go_printjob_handler(job_file=None, pdf_file=None, job_title=None, print_ac
         parent_thread.job_history = parent_thread.job_history[-100:]
 
 
-class X2goPrintJob(threading.Thread):
+class X2GoPrintJob(threading.Thread):
     """\
     For each X2Go print job we create a sub-thread that let's 
     the print job be processed in the background.
