@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,7 @@
 #       none so far
 
 """\
-X2goPulseAudio class - a Pulseaudio daemon guardian thread.
+X2GoPulseAudio class - a Pulseaudio daemon guardian thread.
 
 """
 
@@ -49,7 +49,7 @@ import exceptions
 class OSNotSupportedException(exceptions.StandardError): pass
 """ Exception denoting that this operating system is not supported. """
 
-class X2goPulseAudio(threading.Thread):
+class X2GoPulseAudio(threading.Thread):
     """
     This class controls the Pulse Audio daemon.
     """
@@ -60,11 +60,11 @@ class X2goPulseAudio(threading.Thread):
 
         @param path: full path to pulseaudio.exe
         @type path: C{str}
-        @param client_instance: the calling L{X2goClient} instance
-        @type client_instance: L{X2goClient} instance
-        @param logger: you can pass an L{X2goLogger} object to the L{X2goClientXConfig} constructor
+        @param client_instance: the calling L{X2GoClient} instance
+        @type client_instance: L{X2GoClient} instance
+        @param logger: you can pass an L{X2GoLogger} object to the L{X2GoClientXConfig} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -75,7 +75,7 @@ class X2goPulseAudio(threading.Thread):
             raise OSNotSupportedException('classes of x2go.pulseaudio module are for Windows only')
 
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -90,8 +90,8 @@ class X2goPulseAudio(threading.Thread):
 
     def run(self):
         """\
-        This method is called once the C{X2goPulseAudio.start()} method has been called. To tear 
-        down the Pulseaudio daemon call the L{X2goPulseAudio.stop_thread()} method.
+        This method is called once the C{X2GoPulseAudio.start()} method has been called. To tear 
+        down the Pulseaudio daemon call the L{X2GoPulseAudio.stop_thread()} method.
 
         """
         self._keepalive = True
