@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 
 # The Python X2Go sFTPServer code was originally written by Richard Murri, 
 # for further information see his website: http://www.richardmurri.com
@@ -22,7 +22,7 @@
 
 """\
 For sharing local folders via sFTP/sshfs Python X2Go implements its own sFTP 
-server (as end point of reverse forwarding tunnel requests). Thus, Python X2go
+server (as end point of reverse forwarding tunnel requests). Thus, Python X2Go
 does not need a locally installed SSH daemon on the client side machine.
 
 The Python X2Go sFTP server code was originally written by Richard Murri, 
@@ -55,17 +55,17 @@ class _SSHServer(paramiko.ServerInterface):
 
         @param auth_key: Server key that the client has to authenticate against
         @type auth_key: C{paramiko.RSAKey} instance
-        @param session_instance: the calling L{X2goSession} instance
-        @type session_instance: L{X2goSession} instance
-        @param logger: you can pass an L{X2goLogger} object to the L{X2goClientXConfig} constructor
+        @param session_instance: the calling L{X2GoSession} instance
+        @type session_instance: L{X2GoSession} instance
+        @param logger: you can pass an L{X2GoLogger} object to the L{X2GoClientXConfig} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -162,9 +162,9 @@ class _SFTPServerInterface(paramiko.SFTPServerInterface):
         @type server: C{paramiko.ServerInterface} instance
         @param chroot: chroot environment for this SFTP interface
         @type chroot: C{str}
-        @param logger: you can pass an L{X2goLogger} object to the L{X2goClientXConfig} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the L{X2GoClientXConfig} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
         @param server_event: a C{threading.Event} instance that can signal SFTP session termination
@@ -172,7 +172,7 @@ class _SFTPServerInterface(paramiko.SFTPServerInterface):
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -490,7 +490,7 @@ class _SFTPServerInterface(paramiko.SFTPServerInterface):
             self.server_event.set()
 
 
-class X2goRevFwTunnelToSFTP(rforward.X2goRevFwTunnel):
+class X2GoRevFwTunnelToSFTP(rforward.X2GoRevFwTunnel):
     """\
     A reverse fowarding tunnel with an sFTP server at its endpoint. This blend of a Paramiko/SSH
     reverse forwarding tunnel is used to provide access to local X2Go client folders
@@ -505,22 +505,22 @@ class X2goRevFwTunnelToSFTP(rforward.X2goRevFwTunnel):
         @param server_port: the TCP/IP port on the X2Go server (starting point of the tunnel), 
             normally some number above 30000
         @type server_port: C{int}
-        @param ssh_transport: the L{X2goSession}'s Paramiko/SSH transport instance
+        @param ssh_transport: the L{X2GoSession}'s Paramiko/SSH transport instance
         @type ssh_transport: C{paramiko.Transport} instance
         @param auth_key: Paramiko/SSH RSAkey object that has to be authenticated against by
             the remote sFTP client
         @type auth_key: C{paramiko.RSAKey} instance
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goRevFwTunnelToSFTP} constructor
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoRevFwTunnelToSFTP} constructor
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         self.ready = False
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -541,22 +541,22 @@ class X2goRevFwTunnelToSFTP(rforward.X2goRevFwTunnel):
 
     def run(self):
         """\
-        This method gets run once an L{X2goRevFwTunnelToSFTP} has been started with its
-        L{start()} method. Use L{X2goRevFwTunnelToSFTP}.stop_thread() to stop the
+        This method gets run once an L{X2GoRevFwTunnelToSFTP} has been started with its
+        L{start()} method. Use L{X2GoRevFwTunnelToSFTP}.stop_thread() to stop the
         reverse forwarding tunnel again (refer also to its pause() and resume() method).
 
-        L{X2goRevFwTunnelToSFTP.run()} waits for notifications of an appropriate incoming
-        Paramiko/SSH channel (issued by L{X2goRevFwTunnelToSFTP.notify()}). Appropriate in
+        L{X2GoRevFwTunnelToSFTP.run()} waits for notifications of an appropriate incoming
+        Paramiko/SSH channel (issued by L{X2GoRevFwTunnelToSFTP.notify()}). Appropriate in
         this context means, that its starting point on the X2Go server matches the class's
         property C{server_port}.
 
         Once a new incoming channel gets announced by the L{notify()} method, a new 
-        L{X2goRevFwSFTPChannelThread} instance will be initialized. As a data stream handler,
+        L{X2GoRevFwSFTPChannelThread} instance will be initialized. As a data stream handler,
         the function L{x2go_rev_forward_sftpchannel_handler()} will be used.
 
         The channel will last till the connection gets dropped on the X2Go server side or 
-        until the tunnel gets paused by an L{X2goRevFwTunnelToSFTP.pause()} call or 
-        stopped via the C{X2goRevFwTunnelToSFTP.stop_thread()} method.
+        until the tunnel gets paused by an L{X2GoRevFwTunnelToSFTP.pause()} call or 
+        stopped via the C{X2GoRevFwTunnelToSFTP.stop_thread()} method.
 
         """
         self._request_port_forwarding()
@@ -577,7 +577,7 @@ class X2goRevFwTunnelToSFTP(rforward.X2goRevFwTunnel):
 
             self.incoming_channel.release()
             if self._accept_channels and self._keepalive:
-                _new_chan_thread = X2goRevFwSFTPChannelThread(_chan,
+                _new_chan_thread = X2GoRevFwSFTPChannelThread(_chan,
                                                               target=x2go_rev_forward_sftpchannel_handler, 
                                                               kwargs={ 
                                                                'chan': _chan,
@@ -592,15 +592,15 @@ class X2goRevFwTunnelToSFTP(rforward.X2goRevFwTunnel):
 
 def x2go_rev_forward_sftpchannel_handler(chan=None, auth_key=None, logger=None):
     """\
-    Handle incoming sFTP channels that got setup by an L{X2goRevFwTunnelToSFTP} instance.
+    Handle incoming sFTP channels that got setup by an L{X2GoRevFwTunnelToSFTP} instance.
 
     The channel (and the corresponding connections) close either ...
 
         - ... if the connecting application closes the connection and thus, drops 
         the sFTP channel, or
-        - ... if the L{X2goRevFwTunnelToSFTP} parent thread gets paused. The call
-        of L{X2goRevFwTunnelToSFTP.pause()} on the instance can be used to shut down all incoming 
-        tunneled SSH connections associated to this L{X2goRevFwTunnelToSFTP} instance
+        - ... if the L{X2GoRevFwTunnelToSFTP} parent thread gets paused. The call
+        of L{X2GoRevFwTunnelToSFTP.pause()} on the instance can be used to shut down all incoming 
+        tunneled SSH connections associated to this L{X2GoRevFwTunnelToSFTP} instance
         from within a Python X2Go application.
 
     @param chan: an incoming sFTP channel
@@ -608,8 +608,8 @@ def x2go_rev_forward_sftpchannel_handler(chan=None, auth_key=None, logger=None):
     @param auth_key: Paramiko/SSH RSAkey object that has to be authenticated against by
         the remote sFTP client
     @type auth_key: C{paramiko.RSAKey} instance
-    @param logger: you must pass an L{X2goLogger} object to this handler method
-    @type logger: C{X2goLogger} instance
+    @param logger: you must pass an L{X2GoLogger} object to this handler method
+    @type logger: C{X2GoLogger} instance
 
     """
     if logger is None:
@@ -643,5 +643,5 @@ def x2go_rev_forward_sftpchannel_handler(chan=None, auth_key=None, logger=None):
     logger('sFTP channel %s closed down' % chan, loglevel=log.loglevel_DEBUG)
 
 
-class X2goRevFwSFTPChannelThread(rforward.X2goRevFwChannelThread): pass
-"""A clone of L{rforward.X2goRevFwChannelThread}."""
+class X2GoRevFwSFTPChannelThread(rforward.X2GoRevFwChannelThread): pass
+"""A clone of L{rforward.X2GoRevFwChannelThread}."""
