@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-L{X2goSSHProxy} class - providing a forwarding tunnel for connecting to servers behind firewalls.
+L{X2GoSSHProxy} class - providing a forwarding tunnel for connecting to servers behind firewalls.
 
 """
 __NAME__ = 'x2gosshproxy-pylib'
@@ -47,9 +47,9 @@ from x2go.defaults import X2GO_SSH_ROOTDIR as _X2GO_SSH_ROOTDIR
 import x2go._paramiko
 x2go._paramiko.monkey_patch_paramiko()
 
-class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
+class X2GoSSHProxy(paramiko.SSHClient, threading.Thread):
     """\
-    X2goSSHProxy can be used to proxy X2Go connections through a firewall via SSH.
+    X2GoSSHProxy can be used to proxy X2Go connections through a firewall via SSH.
 
     """
     fw_tunnel = None
@@ -65,7 +65,7 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
                  session_instance=None,
                  logger=None, loglevel=log.loglevel_DEFAULT, ):
         """\
-        Initialize an X2goSSHProxy instance. Use an instance of this class to tunnel X2Go requests through
+        Initialize an X2GoSSHProxy instance. Use an instance of this class to tunnel X2Go requests through
         a proxying SSH server (i.e. to subLANs that are separated by firewalls or to private IP subLANs that
         are NATted behind routers).
 
@@ -125,20 +125,20 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
 
         @param ssh_rootdir: local user's SSH base directory (default: ~/.ssh)
         @type ssh_rootdir: C{str}
-        @param session_instance: the L{X2goSession} instance that builds up this SSH proxying tunnel
-        @type session_instance: L{X2goSession} instance
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goSSHProxy} constructor
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param session_instance: the L{X2GoSession} instance that builds up this SSH proxying tunnel
+        @type session_instance: L{X2GoSession} instance
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoSSHProxy} constructor
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: int
 
-        @raise X2goSSHProxyAuthenticationException: if the SSH proxy caused a C{paramiko.AuthenticationException}
-        @raise X2goSSHProxyException: if the SSH proxy caused a C{paramiko.SSHException}
+        @raise X2GoSSHProxyAuthenticationException: if the SSH proxy caused a C{paramiko.AuthenticationException}
+        @raise X2GoSSHProxyException: if the SSH proxy caused a C{paramiko.SSHException}
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -147,7 +147,7 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
 
         if sshproxy_port: self.port = sshproxy_port
 
-        # translate between X2goSession options and paramiko.SSHCLient.connect() options
+        # translate between X2GoSession options and paramiko.SSHCLient.connect() options
         # if <hostname>:<port> is used for sshproxy_host, then this <port> is used
         if sshproxy_host:
             if sshproxy_host.find(':'):
@@ -207,7 +207,7 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
             self.load_host_keys(self.known_hosts)
 
         if not add_to_known_hosts and session_instance:
-            self.set_missing_host_key_policy(checkhosts.X2goInteractiveAddPolicy(caller=self, session_instance=session_instance))
+            self.set_missing_host_key_policy(checkhosts.X2GoInteractiveAddPolicy(caller=self, session_instance=session_instance))
 
         if add_to_known_hosts:
             self.set_missing_host_key_policy(paramiko.AutoAddPolicy())
@@ -241,10 +241,10 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
 
                 except x2go_exceptions.AuthenticationException, e:
                     self.close()
-                    raise x2go_exceptions.X2goSSHProxyAuthenticationException('pubkey auth mechanisms both failed')
+                    raise x2go_exceptions.X2GoSSHProxyAuthenticationException('pubkey auth mechanisms both failed')
                 except x2go_exceptions.SSHException, e:
                     self.close()
-                    raise x2go_exceptions.X2goSSHProxyAuthenticationException('interactive authentication required')
+                    raise x2go_exceptions.X2GoSSHProxyAuthenticationException('interactive authentication required')
                 except:
                     raise
 
@@ -267,14 +267,14 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
                                 )
                 except x2go_exceptions.AuthenticationException:
                     self.close()
-                    raise x2go_exceptions.X2goSSHProxyAuthenticationException('interactive auth mechanisms failed')
+                    raise x2go_exceptions.X2GoSSHProxyAuthenticationException('interactive auth mechanisms failed')
                 except:
                     self.close()
                     raise
 
         except (x2go_exceptions.SSHException, IOError), e:
             self.close()
-            raise x2go_exceptions.X2goSSHProxyException(str(e))
+            raise x2go_exceptions.X2GoSSHProxyException(str(e))
         except:
             self.close()
             raise
@@ -288,7 +288,6 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
         Wraps around a Paramiko/SSH host key check.
 
         """
-        # hostname rewrite for localhost, force to IPv4
         _hostname = self.hostname
 
         # force into IPv4 for localhost connections
@@ -298,14 +297,14 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
         _valid = False
         (_valid, _hostname, _port, _fingerprint, _fingerprint_type) = checkhosts.check_ssh_host_key(self, _hostname, port=self.port)
         if not _valid and self.session_instance:
-            _valid = self.session_instance.HOOK_check_host_dialog(_hostname, _port, fingerprint=_fingerprint, fingerprint_type=_fingerprint_type)
+            _valid = self.session_instance.HOOK_check_host_dialog(self.remote_host, self.remote_port, fingerprint=_fingerprint, fingerprint_type=_fingerprint_type)
         return _valid
 
     def run(self):
         """\
         Start the SSH proxying tunnel...
 
-        @raise X2goSSHProxyException: if the SSH proxy could not retrieve an SSH transport for proxying a X2Go server-client connection
+        @raise X2GoSSHProxyException: if the SSH proxy could not retrieve an SSH transport for proxying a X2Go server-client connection
 
         """
         if self.get_transport() is not None and self.get_transport().is_authenticated():
@@ -332,7 +331,17 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
                 gevent.sleep(.1)
 
         else:
-            raise x2go_exceptions.X2goSSHProxyException('SSH proxy connection could not retrieve an SSH transport')
+            raise x2go_exceptions.X2GoSSHProxyException('SSH proxy connection could not retrieve an SSH transport')
+
+    def get_local_proxy_host(self):
+        """\
+        Retrieve the local IP socket address this SSH proxying tunnel is (about to) bind/bound to.
+
+        @return: local IP socket address
+        @rtype: C{str}
+
+        """
+        return self.local_host
 
     def get_local_proxy_port(self):
         """\
@@ -344,6 +353,26 @@ class X2goSSHProxy(paramiko.SSHClient, threading.Thread):
         """
         return self.local_port
 
+    def get_remote_host(self):
+        """\
+        Retrieve the remote IP socket address at the remote end of the SSH proxying tunnel.
+
+        @return: remote IP socket address
+        @rtype: C{str}
+
+        """
+        return self.remote_host
+
+    def get_remote_port(self):
+        """\
+        Retrieve the remote IP socket port of the target system's SSH daemon.
+
+        @return: remote SSH port
+        @rtype: C{int}
+
+        """
+        return self.remote_port
+
     def stop_thread(self):
         """\
         Tear down the SSH proxying tunnel.
