@@ -23,7 +23,7 @@ import tempfile
 # Python X2Go modules
 import x2go
 
-class TestX2goClientPrinting(unittest.TestCase):
+class TestX2GoClientPrinting(unittest.TestCase):
 
     def test_client_printing_dialog(self):
         _printing = """\
@@ -42,8 +42,8 @@ defaultprinter=PDF
         tf = tempfile.NamedTemporaryFile()
         print >> tf, _printing
         tf.seek(0)
-        p_action = x2go.backends.printing.X2goClientPrinting(config_files=tf.name, client_instance='DUMMY')
-        self.assertEqual(type(p_action.print_action), x2go.printactions.X2goPrintActionDIALOG)
+        p_action = x2go.backends.printing.X2GoClientPrinting(config_files=tf.name, client_instance='DUMMY')
+        self.assertEqual(type(p_action.print_action), x2go.printactions.X2GoPrintActionDIALOG)
         tf.close()
 
     def test_client_printing_pdfview(self):
@@ -62,8 +62,8 @@ defaultprinter=PDF
         tf = tempfile.NamedTemporaryFile()
         print >> tf, _printing
         tf.seek(0)
-        p_action = x2go.backends.printing.X2goClientPrinting(config_files=tf.name)
-        self.assertEqual(type(p_action.print_action), x2go.printactions.X2goPrintActionPDFVIEW)
+        p_action = x2go.backends.printing.X2GoClientPrinting(config_files=tf.name)
+        self.assertEqual(type(p_action.print_action), x2go.printactions.X2GoPrintActionPDFVIEW)
         tf.close()
 
     def test_client_printing_pdfsave(self):
@@ -82,8 +82,8 @@ defaultprinter=PDF
         tf = tempfile.NamedTemporaryFile()
         print >> tf, _printing
         tf.seek(0)
-        p_action = x2go.backends.printing.X2goClientPrinting(config_files=tf.name)
-        self.assertEqual(type(p_action.print_action), x2go.printactions.X2goPrintActionPDFSAVE)
+        p_action = x2go.backends.printing.X2GoClientPrinting(config_files=tf.name)
+        self.assertEqual(type(p_action.print_action), x2go.printactions.X2GoPrintActionPDFSAVE)
         tf.close()
 
     def test_client_printing_print(self):
@@ -102,8 +102,8 @@ defaultprinter=PDF
         tf = tempfile.NamedTemporaryFile()
         print >> tf, _printing
         tf.seek(0)
-        p_action = x2go.backends.printing.X2goClientPrinting(config_files=tf.name)
-        self.assertEqual(type(p_action.print_action), x2go.printactions.X2goPrintActionPRINT)
+        p_action = x2go.backends.printing.X2GoClientPrinting(config_files=tf.name)
+        self.assertEqual(type(p_action.print_action), x2go.printactions.X2GoPrintActionPRINT)
         tf.close()
 
     def test_client_printing_printcmd(self):
@@ -122,12 +122,12 @@ defaultprinter=PDF
         tf = tempfile.NamedTemporaryFile()
         print >> tf, _printing
         tf.seek(0)
-        p_action = x2go.backends.printing.X2goClientPrinting(config_files=tf.name)
-        self.assertEqual(type(p_action.print_action), x2go.printactions.X2goPrintActionPRINTCMD)
+        p_action = x2go.backends.printing.X2GoClientPrinting(config_files=tf.name)
+        self.assertEqual(type(p_action.print_action), x2go.printactions.X2GoPrintActionPRINTCMD)
         tf.close()
 
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
-    suite.addTest(makeSuite(TestX2goClientPrinting))
+    suite.addTest(makeSuite(TestX2GoClientPrinting))
     return suite
