@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -163,7 +163,7 @@ def _convert_SessionProfileOptions_2_SessionParams(options):
     @param options: a dictionary of options, parameter names as in the X2Go ,,sessions'' file
     @type options: C{dict}
 
-    @return: session options as used in C{X2goSession} instances
+    @return: session options as used in C{X2GoSession} instances
     @rtype: C{dict}
 
     """
@@ -205,7 +205,6 @@ def _convert_SessionProfileOptions_2_SessionParams(options):
             'sshproxyport': 'sshproxy_port',
             'sshproxyuser': 'sshproxy_user',
             'sshproxykeyfile': 'sshproxy_key_filename',
-            'sshproxytunnel': 'sshproxy_tunnel',
             'sessiontitle': 'session_title',
             'setsessiontitle': 'set_session_title',
             'published': 'published_applications',
@@ -214,6 +213,7 @@ def _convert_SessionProfileOptions_2_SessionParams(options):
             'forwardsshagent': 'forward_sshagent',
             'autologin': 'look_for_keys',
             'sshproxyautologin': 'sshproxy_look_for_keys',
+            'uniquehostkeyaliases': 'unique_hostkey_aliases',
     }
     _speed_dict = {
             '0': 'modem',
@@ -328,7 +328,20 @@ def _convert_SessionProfileOptions_2_SessionParams(options):
         _params['sshproxy_key_filename'] = _params['key_filename']
     del _params['sshproxysamepass']
 
-    # currently known but ignored in Python X2go
+    if _params['use_sshproxy']:
+
+        # compat code for Python X2Go 0.2.1.0 -> 0.2.2.0
+        if options.has_key('sshproxytunnel'):
+            if not options['sshproxytunnel'].startswith('DEPRECATED'):
+                _params['server'] = options['sshproxytunnel'].split(":")[-2]
+                _params['port'] = options['sshproxytunnel'].split(":")[-1]
+            try: del _params['sshproxytunnel']
+            except KeyError: pass
+
+        _params['sshproxy_tunnel'] = 'localhost:44444:%s:%s' % (_params['server'], _params['port'])
+
+
+    # currently known but ignored in Python X2Go
     _ignored_options = [
             'startsoundsystem',
             'soundtunnel',
@@ -336,6 +349,7 @@ def _convert_SessionProfileOptions_2_SessionParams(options):
             'icon',
             'xinerama',
             'multidisp',
+            'display',
             'krblogin',
             'directrdp',
             'directrdpsettings',
@@ -353,7 +367,7 @@ def session_names_by_timestamp(session_infos):
     """\
     Sorts session profile names by their timestamp (as used in the file format's section name).
 
-    @param session_infos: a dictionary of session infos as reported by L{X2goClient.list_sessions()}
+    @param session_infos: a dictionary of session infos as reported by L{X2GoClient.list_sessions()}
     @type session_infos: C{dict}
 
     @return: a timestamp-sorted list of session names found in C{session_infos}
@@ -773,7 +787,7 @@ class ProgressStatus(object):
 
     def __iter__(self):
         """\
-        Intialize the L{ProgresStatus} iterator object.
+        Intialize the L{ProgressStatus} iterator object.
 
         """
         self.status = self.progress_func()
