@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -43,9 +43,9 @@ from defaults import X2GO_CLIENTXCONFIG_DEFAULTS as _X2GO_CLIENTXCONFIG_DEFAULTS
 import inifiles
 import utils
 
-class X2goClientXConfig(inifiles.X2goIniFile):
+class X2GoClientXConfig(inifiles.X2GoIniFile):
     """\
-    Configuration file based XServer startup settings for X2goClient instances.
+    Configuration file based XServer startup settings for X2GoClient instances.
 
     This class is needed for Windows systems and (maybe soon) for Unix desktops using Wayland.
 
@@ -54,11 +54,11 @@ class X2goClientXConfig(inifiles.X2goIniFile):
 
     def __init__(self, config_files=_X2GO_XCONFIG_CONFIGFILES, defaults=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        Constructs an L{X2goClientXConfig} instance. This is normally done by an L{X2goClient} instance.
-        You can retrieve this L{X2goClientXConfig} instance with the C{X2goClient.get_client_xconfig()} 
+        Constructs an L{X2GoClientXConfig} instance. This is normally done by an L{X2GoClient} instance.
+        You can retrieve this L{X2GoClientXConfig} instance with the C{X2GoClient.get_client_xconfig()} 
         method.
 
-        On construction the L{X2goClientXConfig} instance is filled with values from the configuration files::
+        On construction the L{X2GoClientXConfig} instance is filled with values from the configuration files::
 
             /etc/x2goclient/xconfig
             ~/.x2goclient/xconfig
@@ -71,9 +71,9 @@ class X2goClientXConfig(inifiles.X2goIniFile):
         @type config_files: C{list}
         @param defaults: a Python dictionary with configuration file defaults (use on your own risk)
         @type defaults: C{dict}
-        @param logger: you can pass an L{X2goLogger} object to the L{X2goClientXConfig} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the L{X2GoClientXConfig} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -83,7 +83,7 @@ class X2goClientXConfig(inifiles.X2goIniFile):
             class OSNotSupportedException(exceptions.StandardError): pass
             raise OSNotSupportedException('classes of x2go.xserver module are for Windows only')
 
-        inifiles.X2goIniFile.__init__(self, config_files, defaults=defaults, logger=logger, loglevel=loglevel)
+        inifiles.X2GoIniFile.__init__(self, config_files, defaults=defaults, logger=logger, loglevel=loglevel)
 
         _known_xservers = utils.merge_ordered_lists(self.defaultValues['XServers']['known_xservers'], self.known_xservers)
 
@@ -155,7 +155,7 @@ class X2goClientXConfig(inifiles.X2goIniFile):
     @property
     def xserver_launch_possible(self):
         """\
-        Detect if there is an XServer (that is known to Python X2go) installed on the system.
+        Detect if there is an XServer (that is known to Python X2Go) installed on the system.
         Equals C{True} if we have found an installed XServer that we can launch.
 
         """
@@ -239,7 +239,7 @@ class X2goClientXConfig(inifiles.X2goIniFile):
             pass
 
 
-class X2goXServer(threading.Thread):
+class X2GoXServer(threading.Thread):
     """
     This class is responsible for starting/stopping an external XServer application.
 
@@ -253,11 +253,11 @@ class X2goXServer(threading.Thread):
 
         @param xserver_name: name of the XServer to start (refer to the xconfig file for available names)
         @type xserver_name: C{str}
-        @param xserver_config: XServer configuration node (as derived from L{X2goClientXConfig.get_xserver_config()}
+        @param xserver_config: XServer configuration node (as derived from L{X2GoClientXConfig.get_xserver_config()}
         @type xserver_config: C{dict}
-        @param logger: you can pass an L{X2goLogger} object to the L{X2goClientXConfig} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the L{X2GoClientXConfig} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -268,7 +268,7 @@ class X2goXServer(threading.Thread):
             raise OSNotSupportedException('classes of x2go.xserver module are for Windows only')
 
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -296,7 +296,7 @@ class X2goXServer(threading.Thread):
 
     def run(self):
         """\
-        Start this L{X2goXServer} thread. This will launch the configured XServer application.
+        Start this L{X2GoXServer} thread. This will launch the configured XServer application.
 
         """
         self._keepalive = True
